@@ -52,27 +52,26 @@ class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
     ifaces = (GSMInterface, BTInterface, WLANInterface)#, FlightMode)
     self.__smi_box = gtk.Table(len(ifaces), 1, True)
     self.add(self.__smi_box)
-    ilist = enumerate(ifaces)
 
     loaded_list = ''
-    loaded_ifaces = 0
-    for iface in ilist:
+    ind = 0
+    for iface in ifaces:
       try:
-        self.__interfaces.append(iface[1](self.__bus, self.process_sai, 
-                                          self.__show_settings_dialog))
-        self.__smi_box.attach(self.__interfaces[iface[0]].get_button(), 
-                              iface[0], iface[0]+1, 0, 1, 
+        obj = iface(self.__bus, self.process_sai, self.__show_settings_dialog)
+        self.__interfaces.append(obj)
+        self.__smi_box.attach(self.__interfaces[ind].get_button(), 
+                              ind, ind + 1, 0, 1, 
                               gtk.EXPAND | gtk.FILL, 
                               gtk.SHRINK)
-        loaded_ifaces += 1
         loaded_list = '%s\n%s (%s)' % (loaded_list, 
-                                  self.__interfaces[iface[0]].get_name(),
-                                  self.__interfaces[iface[0]].__class__)
+                                  self.__interfaces[ind].get_name(),
+                                  self.__interfaces[ind].__class__)
+        ind += 1
       except Exception, e:
-        loaded_list = '%s\n%s\nError: %s\n' % (loaded_list, iface[1], e)
+        loaded_list = '%s\n%s\nError: %s\n' % (loaded_list, iface, e)
         pass
     print '\n%s\n%s' % (self.app_name, self.version)
-    print '\nLoaded (%s/%s)%s\n' % (loaded_ifaces, len(ifaces), loaded_list)
+    print '\nLoaded (%s/%s)%s\n' % (ind, len(ifaces), loaded_list)
     self.show_all()
 #    self.__show_settings_dialog()
 
