@@ -12,24 +12,25 @@ from advifswlib.interfaces.Abstract import InterfaceState, AbstractInterface
 from advpowcommon.util.execn import *
 
 class BTInterface(AbstractInterface):
-
-  bt_adapter_iface = 'org.bluez.Adapter'
-  bt_device_iface = 'org.bluez.Device'
-  bt_adapter_signal = 'PropertyChanged'
-  bt_device_signal = 'PropertyChanged'
-  bt_adapter_path = get_shell_command_output('dbus-send --system --dest=org.bluez --print-reply / org.bluez.Manager.DefaultAdapter | tail -1 | sed \'s/^.*"\\(.*\\)".*$/\\1/\' 2>/dev/null')\
-                    .replace('\n', '')
-  bt_device_path = None
-
   def pre_init(self):
+    self.interfaces = {'BlueZAdapter': ['org.bluez',
+                                        get_shell_command_output('dbus-send --system --dest=org.bluez --print-reply / org.bluez.Manager.DefaultAdapter | tail -1 | sed \'s/^.*"\\(.*\\)".*$/\\1/\' 2>/dev/null').replace('\n', ''),
+                                        'org.bluez.Adapter',
+                                        None,
+                                        True],
+                        'BlueZDevice': ['org.bluez',
+                                        None,
+                                        'org.bluez.Device',
+                                        None,
+                                        True]}
     self.state = {'name': 'Bluetooth',
-                  'dbus': {'on': {'name': self.bt_adapter_signal, 
-                                  'iface': self.bt_adapter_iface,
-                                  'path': self.bt_adapter_path,
+                  'dbus': {'on': {'name': 'PropertyChanged',
+                                  'iface': self.interfaces['BlueZAdapter'][2],
+                                  'path': self.interfaces['BlueZAdapter'][1],
                                   'args': {}},
-                           'connected': {'name': self.bt_device_signal, 
-                                         'iface': self.bt_device_iface, 
-                                         'path': self.bt_device_path, 
+                           'connected': {'name': 'PropertyChanged',
+                                         'iface': self.interfaces['BlueZDevice'][2],
+                                         'path': self.interfaces['BlueZDevice'][1],
                                          'args': {'path_keyword': 'path'}}
                           },
                   'images': ('ifsw_statusarea_bluetooth_off', 
@@ -43,20 +44,18 @@ class BTInterface(AbstractInterface):
                   'strength': 0,
                   'modes': ('bluetooth-connectable', 'bluetooth-discoverable'),
                   'mode': 0}
-    self.interfaces = {'BlueZAdapter': ['org.bluez', self.bt_adapter_path, 
-                                        self.bt_adapter_iface, '', True]}
     self.connected_device = set()
 
   def process_signal_connected(self, prop, value, **kwargs):
     if str(prop) == 'Connected':
-      device = kwargs['path'].replace('%s/' % self.bt_adapter_path, '')
+      device = kwargs['path'].replace('%s/' % self.interfaces['BlueZAdapter'][1], '')
       if value:
         self.connected_device.add(device)
         return InterfaceState.connected, None, None
       else:
         try:
           self.connected_device.remove(device)
-        except KeyError, e:
+        except KeyError:
           pass
         if len(self.connected_device) == 0:
           return self.get_status()
@@ -66,10 +65,9 @@ class BTInterface(AbstractInterface):
   def process_signal_on(self, prop, value, **kwargs):
     prop = str(prop)
     if (prop == 'Powered'):
-      if int(value):
-        return InterfaceState.on, None, None
-      else:
-        return InterfaceState.off, None, None
+      return InterfaceState.on if int(value) else InterfaceState.off,\
+             None,\
+             None
     elif (prop == 'Discoverable'):
       return None, int(value), None
     else:
@@ -77,14 +75,10 @@ class BTInterface(AbstractInterface):
 
   def get_status(self):
     props = self.get_interface('BlueZAdapter').GetProperties()
-    if props['Powered']:
-      discoverable = int(props['Discoverable'])
-      if int(props['Powered']):
-        return InterfaceState.on, discoverable, 0
-      else:
-        return InterfaceState.off, discoverable, 0
-    else:
-      return 0, 0, 0
+    discoverable = int(props['Discoverable'])
+    return InterfaceState.on if int(props['Powered']) else InterfaceState.off,\
+           discoverable,\
+           0
 
   def turn_on(self):
     gobject.idle_add(self.run_commands, True)
@@ -93,12 +87,12 @@ class BTInterface(AbstractInterface):
     for device in self.connected_device:
       try:
         conndev_iface = dbus.Interface(self.get_bus()\
-                                       .get_object('org.bluez', 
-                                                   '%s/%s' % 
-                                                   (self.bt_adapter_path, 
-                                                    device), 
-                                                   introspect=True), 
-                                       self.bt_device_iface)
+                                       .get_object(self.interfaces['BlueZDevice'][0],
+                                                   '%s/%s' %
+                                                   (self.interfaces['BlueZAdapter'][1],
+                                                    device),
+                                                   introspect=True),
+                                       self.interfaces['BlueZDevice'][2])
         conndev_iface.Disconnect()
       except:
         pass
