@@ -45,13 +45,18 @@ class WLANInterface(AbstractInterface):
   #ICD_STATE_SEARCH_STOP		9
   #ICD_STATE_INTERNAL_ADDRESS_ACQUIRED	15
 
+  #kp51: enormously insane packaging
+  #/opt/packet-injection-modules/2.6.28.10-power51/
+  #why not just:
+  #/opt/lib/modules/2.6.28.10-power51/packet-injection/
+
   wifi_cmd = {'up': 'sudo /usr/bin/advifsw/wlan_up.sh',
               'down': 'sudo /usr/bin/advifsw/wlan_down.sh',
               'unload': 'sudo /usr/bin/advifsw/wlan_unload.sh',
               'load0': 'sudo /usr/bin/advifsw/wlan_load0.sh',
               'load1': 'sudo /usr/bin/advifsw/wlan_load1.sh',
               'get_driver': "lsmod | grep '^wl12\([x]\{2\}\|51\)\ ' | sed -n s/\ .*//p",
-              'check_be': 'if [ -d /lib/modules/`uname -r` ]; then echo 1; fi'
+              'check_be': 'if [ -d /opt/lib/modules/`uname -r` ]; then echo 1; fi'
              }
   # off: down > unload
   wifi_turn_off_cmd = [wifi_cmd['down'], wifi_cmd['unload']]
