@@ -1,6 +1,6 @@
 #!/bin/sh
-stop wlancond
-sleep 1
+#stop wlancond
+#sleep 1
 start wlancond
 ifconfig wlan0 up
 sleep 1
